@@ -312,7 +312,7 @@ QVariant CGroupList::data(const QModelIndex &index, int role) const
                             switch(grp->type())
                             {
                                 case CGroupListItem::ALL:
-                                    return SmallIcon("preferences-desktop-font");
+                                    return SmallIcon("font");
                                 case CGroupListItem::PERSONAL:
                                     return SmallIcon("user-identity");
                                 case CGroupListItem::SYSTEM:
@@ -569,7 +569,7 @@ bool CGroupList::removeGroup(const QModelIndex &idx)
         CGroupListItem *grp=static_cast<CGroupListItem *>(idx.internalPointer());
 
         if(grp && grp->isCustom() &&
-           KMessageBox::Yes==KMessageBox::warningYesNo(itsParent,
+           KMessageBox::Continue==KMessageBox::warningContinueCancel(itsParent,
                                           i18n("<p>Do you really want to remove \'<b>%1</b>\'?</p>"
                                                "<p><i>This will only remove the group, and not "
                                                "the actual fonts.</i></p>", grp->name()),
@@ -703,7 +703,7 @@ void CGroupList::sort(int, Qt::SortOrder order)
 {
     itsSortOrder=order;
 
-    qSort(itsGroups.begin(), itsGroups.end(),
+    std::sort(itsGroups.begin(), itsGroups.end(),
           Qt::AscendingOrder==order ? groupNameLessThan : groupNameGreaterThan);
 
     emit layoutChanged();
